from datetime import datetime
from enum import Enum, auto


class SpamRefinerType:
    def __str__(self) -> str:
        return f'<{self.__class__.__name__}: {self.__dict__}>'

    def __repr__(self) -> str:
        return self.__str__()


class Flag(SpamRefinerType):
    user_id: int
    flagged: str
    reason: str

    def __init__(self,
                 flagged: str,
                 reason: str,
                 user_id: int,
                 **kwargs) -> None:
        self.user_id = user_id
        self.flagged = flagged
        self.reason = reason


from typing import Union
from .types import Flag
import requests


class Client:
    def __init__(self, token: str, *, host: str = 'http://api.spamrefiner.org') -> None:
        self._host = host
        self._token = token

    def get_flag(self, user_id: int) -> Union[Flag, bool]:
        try:
            data = requests.get(f"{self._host}/find?id={user_id}&token={self._token}")
            req = data.json()
            if req.get("error"):
                if req["error"] == "invalid token":
                    error = "Please check your API Token, It seems to be incorrect!"
                else:
                    error = req["error"]
                return error
            elif req.get("reason"):
                return Flag(**req)
            else:
                return "User not flagged"
        except:
            error = "Unknown Error Occured"
            return error
